# Edumated [![PyPI Version](https://img.shields.io/pypi/v/edumated.svg)](https://pypi.org/project/edumated)
> When you've check mated ♔ [edumate](https://www.edumate.com.au/)


## Setup
### Installation
Make sure you have a recent version of python installed and you should be fine.
Run
`pip install edumated`

Or to get the bleeding edge version
`pip install git+https://github.com/joelbryla/edumated`

### Authentication
To be able to use this tool you'll first have to create a calendar that you will
add the events to.  To create a new google calendar simply click [here](https://calendar.google.com/calendar/r/settings/createcalendar).
Once you've created the calendar click on the configure button and scroll down
to the *Integrate Calendar* and copy the Calendar ID.  Now when running
edumated, when it asks for your calendar id input the one you just copied
before.
